@@ -143,9 +143,10 @@ class Lexer:
                     else:
                         if m.start() != 0:
                             st1.append(s1[0:m.start()])
-                        if fun == "":
-                            st1.append(("",s1[m.start():m.end()]))
-                        else:
+#                        if fun == "":
+#                            st1.append(("",s1[m.start():m.end()]))
+#                        else:
+                        if fun != "":    
                             st1.append(apply(fun,[s1[m.start():m.end()]]))
                         if m.end() == len(s1):
                             break
@@ -1824,7 +1825,7 @@ def EmptySemRule(sargs,context={}):
 class Yappy_grammar(Yappy):
     """ A parser for grammar rules. See C{test()} for an example. """
     
-    def __init__(self,no_table=1, table='yappypar.tab',**args):
+    def __init__(self,no_table=1, table='yappypar.tab',tabletype=LR1table,**args):
         grammar= grules([
         ("G -> RULE G",self.GRule),
         ("G -> []",EmptySemRule),
